@@ -58,7 +58,7 @@ def cardmain(clargs=None):
     filename, _ = splitext(args.cardfile)
     filename += ".crd"
 
-    if not exists(dirname(filename)):
+    if dirname(filename) and not exists(dirname(filename)):
         makedirs(dirname(filename))
 
     with open(filename, "w") as cardfile:
